Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/api.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/api.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/api.txt	(revision 7811)
@@ -1,6 +1,6 @@
-:mod:`waeup.sirp.utils` -- misc. helpers
+:mod:`waeup.kofa.utils` -- misc. helpers
 ****************************************
 
-.. module:: waeup.sirp.utils
+.. module:: waeup.kofa.utils
 
 Components and other stuff of general interest.
@@ -9,5 +9,5 @@
 ==========
 
-The :mod:`waeup.sirp.utils` module provides the following submodules:
+The :mod:`waeup.kofa.utils` module provides the following submodules:
 
 .. toctree::
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.txt	(revision 7811)
@@ -1,3 +1,3 @@
-:mod:`waeup.sirp.utils.batching` -- Batch processing
+:mod:`waeup.kofa.utils.batching` -- Batch processing
 ****************************************************
 
@@ -188,5 +188,5 @@
 All we need, is a batch processor now.
 
-    >>> from waeup.sirp.utils.batching import BatchProcessor
+    >>> from waeup.kofa.utils.batching import BatchProcessor
     >>> class CaveProcessor(BatchProcessor):
     ...   util_name = 'caveprocessor'
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.py	(revision 7811)
@@ -27,5 +27,5 @@
 from zope.interface import Interface
 from zope.publisher.browser import TestRequest
-from waeup.sirp.interfaces import IObjectConverter
+from waeup.kofa.interfaces import IObjectConverter
 
 class ExtendedCheckBoxWidget(CheckBoxWidget):
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/converters.txt	(revision 7811)
@@ -1,6 +1,6 @@
-:mod:`waeup.sirp.utils.converters` -- Converters
+:mod:`waeup.kofa.utils.converters` -- Converters
 ************************************************
 
-.. module:: waeup.sirp.utils.converters
+.. module:: waeup.kofa.utils.converters
 
 Converters for :mod:`zope.schema` based data.
@@ -10,5 +10,5 @@
 
 .. :NOdoctest:
-.. :NOlayer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :NOlayer: waeup.kofa.testing.KOFAUnitTestLayer
 
 
@@ -21,5 +21,5 @@
    'non-values'. Current setting is:
 
-      >>> from waeup.sirp.utils.converters import NONE_STRING_VALUE
+      >>> from waeup.kofa.utils.converters import NONE_STRING_VALUE
       >>> NONE_STRING_VALUE
       ''
@@ -32,5 +32,5 @@
 ========
 
-The :mod:`waeup.sirp.utils.converters` module is basically a collection of
+The :mod:`waeup.kofa.utils.converters` module is basically a collection of
 adapters for field types of :mod:`zope.schema`.
 
@@ -48,5 +48,5 @@
    `zope.schema.Choice` or similar.
 
-   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.kofa.interfaces.ISchemaTypeConverter)
 
    .. method:: _convertValueFromString(string)
@@ -111,5 +111,5 @@
    .. method:: adapts(zope.schema.IText)
 
-   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.kofa.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -150,5 +150,5 @@
    .. method:: adapts(zope.schema.IBool)
 
-   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.kofa.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -191,5 +191,5 @@
    .. method:: adapts(zope.schema.IInt)
 
-   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.kofa.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=True])
@@ -232,5 +232,5 @@
    .. method:: adapts(zope.schema.IChoice)
 
-   .. method:: provides(waeup.sirp.interfaces.ISchemaTypeConverter)
+   .. method:: provides(waeup.kofa.interfaces.ISchemaTypeConverter)
 
    .. method:: fromString(string[, strict=False])
@@ -272,5 +272,5 @@
 ----------------------
 
-.. autoclass:: waeup.sirp.utils.converters.DateConverter
+.. autoclass:: waeup.kofa.utils.converters.DateConverter
    :members:
    :inherited-members:
@@ -294,10 +294,10 @@
 :class:`TextConverter` instance:
 
-    >>> from waeup.sirp.utils.converters import TextConverter
+    >>> from waeup.kofa.utils.converters import TextConverter
     >>> converter = TextConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
+    >>> from waeup.kofa.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -305,5 +305,5 @@
 
     >>> converter
-    <waeup.sirp.utils.converters.TextConverter object at 0x...>
+    <waeup.kofa.utils.converters.TextConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -382,10 +382,10 @@
 :class:`BoolConverter` instance:
 
-    >>> from waeup.sirp.utils.converters import BoolConverter
+    >>> from waeup.kofa.utils.converters import BoolConverter
     >>> converter = BoolConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
+    >>> from waeup.kofa.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -393,5 +393,5 @@
 
     >>> converter
-    <waeup.sirp.utils.converters.BoolConverter object at 0x...>
+    <waeup.kofa.utils.converters.BoolConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -494,10 +494,10 @@
 :class:`IntConverter` instance:
 
-    >>> from waeup.sirp.utils.converters import IntConverter
+    >>> from waeup.kofa.utils.converters import IntConverter
     >>> converter = IntConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
+    >>> from waeup.kofa.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -505,5 +505,5 @@
 
     >>> converter
-    <waeup.sirp.utils.converters.IntConverter object at 0x...>
+    <waeup.kofa.utils.converters.IntConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -597,10 +597,10 @@
 :class:`ChoiceConverter` instance:
 
-    >>> from waeup.sirp.utils.converters import ChoiceConverter
+    >>> from waeup.kofa.utils.converters import ChoiceConverter
     >>> converter = ChoiceConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
+    >>> from waeup.kofa.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -608,5 +608,5 @@
 
     >>> converter
-    <waeup.sirp.utils.converters.ChoiceConverter object at 0x...>
+    <waeup.kofa.utils.converters.ChoiceConverter object at 0x...>
 
 Now we can convert strings to this type:
@@ -672,9 +672,9 @@
     '1'
 
-    >>> from waeup.sirp.interfaces import SimpleSIRPVocabulary
+    >>> from waeup.kofa.interfaces import SimpleKOFAVocabulary
     >>> field = Choice(
     ...   title = u'Favourite Dish',
     ...   default = 0,
-    ...   vocabulary = SimpleSIRPVocabulary(
+    ...   vocabulary = SimpleKOFAVocabulary(
     ...        ('N/A', 0), ('Pizza', 1),
     ...        ('Cake', 2), ('Muffins', 3)),
@@ -730,5 +730,5 @@
 
 We get a converter for this field in the usual way. The
-:meth:`waeup.sirp.utils.converters.fromString()` method will return one of
+:meth:`waeup.kofa.utils.converters.fromString()` method will return one of
 the objects if we feed it with ``'Wilma'`` or ``'Fred'``:
 
@@ -763,10 +763,10 @@
 :class:`IntConverter` instance:
 
-    >>> from waeup.sirp.utils.converters import DateConverter
+    >>> from waeup.kofa.utils.converters import DateConverter
     >>> converter = DateConverter(field)
 
 Or we can just grab a registered adapter:
 
-    >>> from waeup.sirp.interfaces import ISchemaTypeConverter
+    >>> from waeup.kofa.interfaces import ISchemaTypeConverter
     >>> converter = ISchemaTypeConverter(field)
 
@@ -774,5 +774,5 @@
 
     >>> converter
-    <waeup.sirp.utils.converters.DateConverter object at 0x...>
+    <waeup.kofa.utils.converters.DateConverter object at 0x...>
 
 Now we can convert strings to this type:
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.txt	(revision 7811)
@@ -1,8 +1,8 @@
-:mod:`waeup.sirp.utils.helpers` -- Helpers for SIRP
+:mod:`waeup.kofa.utils.helpers` -- Helpers for KOFA
 ***************************************************
 
-.. module:: waeup.sirp.utils.helpers
-
-Helper functions for SIRP.
+.. module:: waeup.kofa.utils.helpers
+
+Helper functions for KOFA.
 
 .. :doctest:
@@ -21,5 +21,5 @@
      >>> os.chdir(new_location)
 
-     >>> from waeup.sirp.utils.helpers import remove_file_or_directory
+     >>> from waeup.kofa.utils.helpers import remove_file_or_directory
      >>> open('blah', 'wb').write('nonsense')
      >>> 'blah' in os.listdir('.')
@@ -72,5 +72,5 @@
      >>> open(os.path.join('src', 'blah'), 'wb').write('nonsense')
 
-     >>> from waeup.sirp.utils.helpers import copy_filesystem_tree
+     >>> from waeup.kofa.utils.helpers import copy_filesystem_tree
      >>> result = copy_filesystem_tree('src', 'dst')
 
@@ -179,5 +179,5 @@
    returned with all preceeding/following stuff stripped:
 
-     >>> from waeup.sirp.utils.helpers import get_inner_HTML_part
+     >>> from waeup.kofa.utils.helpers import get_inner_HTML_part
      >>> print get_inner_HTML_part("""<html>
      ... <head>
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.txt
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.txt	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.txt	(revision 7811)
@@ -6,5 +6,5 @@
 
 .. :doctest:
-.. :layer: waeup.sirp.testing.SIRPUnitTestLayer
+.. :layer: waeup.kofa.testing.KOFAUnitTestLayer
 
 As imports and exports of data are a cruical point when doing updates
@@ -60,8 +60,8 @@
 an exporter::
 
-    >>> from waeup.sirp.interfaces import ISIRPXMLExporter
-    >>> exporter = ISIRPXMLExporter(mycave)
+    >>> from waeup.kofa.interfaces import IKOFAXMLExporter
+    >>> exporter = IKOFAXMLExporter(mycave)
     >>> exporter
-    <waeup.sirp.utils.importexport.XMLExporter object at 0x...>
+    <waeup.kofa.utils.importexport.XMLExporter object at 0x...>
 
 All exporters provide an ``export(<obj>)`` method::
@@ -101,6 +101,6 @@
 Now we create an importer for that object:
 
-    >>> from waeup.sirp.interfaces import ISIRPXMLImporter
-    >>> importer = ISIRPXMLImporter(mycave)
+    >>> from waeup.kofa.interfaces import IKOFAXMLImporter
+    >>> importer = IKOFAXMLImporter(mycave)
 
 Importing from filenames
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_batching.py	(revision 7811)
@@ -27,6 +27,6 @@
 from zope.component.interfaces import IFactory
 from zope.interface import Interface, implements
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
 
 optionflags = (
@@ -71,5 +71,5 @@
 stoneville = dict
 
-from waeup.sirp.utils.batching import BatchProcessor
+from waeup.kofa.utils.batching import BatchProcessor
 class CaveProcessor(BatchProcessor):
     util_name = 'caveprocessor'
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_converters.py	(revision 7811)
@@ -31,17 +31,17 @@
     Interface, implements, invariant, Invalid, implementedBy)
 
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-from waeup.sirp.university import Faculty
-from waeup.sirp.utils.converters import IObjectConverter
-from waeup.sirp.utils.helpers import attrs_to_fields
-from waeup.sirp.interfaces import SimpleSIRPVocabulary
-
-colors = SimpleSIRPVocabulary(
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+from waeup.kofa.university import Faculty
+from waeup.kofa.utils.converters import IObjectConverter
+from waeup.kofa.utils.helpers import attrs_to_fields
+from waeup.kofa.interfaces import SimpleKOFAVocabulary
+
+colors = SimpleKOFAVocabulary(
     ('Red', u'red'),
     ('Green', u'green'),
     ('Blue', u'blue'),
     )
-car_nums = SimpleSIRPVocabulary(
+car_nums = SimpleKOFAVocabulary(
     ('None', 0),
     ('One', 1),
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_doctests.py	(revision 7811)
@@ -18,5 +18,5 @@
 """Register doctests from utils subpackage.
 """
-from waeup.sirp.testing import get_doctest_suite
+from waeup.kofa.testing import get_doctest_suite
 
 def test_suite():
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_helpers.py	(revision 7811)
@@ -27,5 +27,5 @@
 from zope.security.testing import Principal, Participation
 from zope.security.management import newInteraction, endInteraction
-from waeup.sirp.utils import helpers
+from waeup.kofa.utils import helpers
 
 from zope.interface import Interface, implements
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/batching.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """SIRP components for batch processing.
 
 Batch processors eat CSV files to add, update or remove large numbers
@@ -31,5 +31,5 @@
 from zope.interface import Interface
 from zope.schema import getFields
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IBatchProcessor, FatalCSVError, DuplicationError, IObjectConverter)
 
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""SIRP components for batch processing.
+"""KOFA components for batch processing.
 
 Batch processors eat CSV files to add, update or remove large numbers
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/helpers.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """General helper functions for SIRP.
 """
 import os
@@ -151,5 +151,5 @@
     instances of certain classes when called.
 
-    In :mod:`waeup.sirp` we use factories extensively for
+    In :mod:`waeup.kofa` we use factories extensively for
     batching. While processing a batch some importer looks up a
     factory to create real-world instances that then get filled with
@@ -163,5 +163,5 @@
 
        >>> import grok
-       >>> from waeup.sirp.utils.helpers import FactoryBase
+       >>> from waeup.kofa.utils.helpers import FactoryBase
        >>> class MyObject(object):
        ...   # Some class we want to get instances of.
@@ -169,5 +169,5 @@
        >>> class MyObjectFactory(FactoryBase):
        ...   # This is the factory for MyObject instances
-       ...   grok.name(u'waeup.sirp.factory.MyObject')
+       ...   grok.name(u'waeup.kofa.factory.MyObject')
        ...   factory = MyObject
 
@@ -176,5 +176,5 @@
     called. The given name must even be unique amongst all utilities
     registered during runtime. While you can pick any name you like
-    you might want to prepend ``waeup.sirp.factory.`` to the name
+    you might want to prepend ``waeup.kofa.factory.`` to the name
     string to make sure it does not clash with names of other
     utilities one day.
@@ -183,8 +183,8 @@
     freshly defined factory. This executes all the component
     registration stuff we don't want to do ourselves. In daily use
-    this is done automatically on startup of a :mod:`waeup.sirp`
+    this is done automatically on startup of a :mod:`waeup.kofa`
     system.
 
-       >>> grok.testing.grok('waeup.sirp.utils.helpers')
+       >>> grok.testing.grok('waeup.kofa.utils.helpers')
        >>> grok.testing.grok_component(
        ...    'MyObjectFactory', MyObjectFactory
@@ -197,5 +197,5 @@
 
        >>> from zope.component import createObject
-       >>> obj = createObject('waeup.sirp.factory.MyObject')
+       >>> obj = createObject('waeup.kofa.factory.MyObject')
        >>> isinstance(obj, MyObject)
        True
@@ -207,5 +207,5 @@
        >>> from zope.component.interfaces import IFactory
        >>> factory = getUtility(
-       ...   IFactory, name='waeup.sirp.factory.MyObject'
+       ...   IFactory, name='waeup.kofa.factory.MyObject'
        ...   )
        >>> isinstance(factory, MyObjectFactory)
@@ -251,5 +251,5 @@
     HTML code:
 
-        >>> from waeup.sirp.utils.helpers import ReST2HTML
+        >>> from waeup.kofa.utils.helpers import ReST2HTML
         >>> source = '''
         ... Headline
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""General helper functions for SIRP.
+"""General helper functions for KOFA.
 """
 import os
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/importexport.py	(revision 7811)
@@ -22,6 +22,6 @@
 from cStringIO import StringIO
 from zope.interface import Interface
-from waeup.sirp.interfaces import (ISIRPObject, ISIRPExporter,
-                                   ISIRPXMLExporter, ISIRPXMLImporter)
+from waeup.kofa.interfaces import (IKOFAObject, IKOFAExporter,
+                                   IKOFAXMLExporter, IKOFAXMLImporter)
 
 def readFile(f):
@@ -40,11 +40,11 @@
 
 class Exporter(grok.Adapter):
     """Export a SIRP object as pickle.
 
     This all-purpose exporter exports attributes defined in schemata
     and contained objects (if the exported thing is a container).
     """
-    grok.context(ISIRPObject)
-    grok.provides(ISIRPExporter)
+    grok.context(IKOFAObject)
+    grok.provides(IKOFAExporter)
 
     def __init__(self, context):
@@ -61,5 +61,5 @@
 
 class XMLExporter(grok.Adapter):
     """Export a SIRP object as XML.
 
     This all-purpose exporter exports XML representations of pickable
@@ -67,9 +67,9 @@
     """
     grok.context(Interface)
-    grok.provides(ISIRPXMLExporter)
+    grok.provides(IKOFAXMLExporter)
 
     def __init__(self, context):
         self.context = context
-    
+
     def export(self, filepath=None):
         pickled_obj = cPickle.dumps(self.context)
@@ -84,12 +84,12 @@
 
 class XMLImporter(grok.Adapter):
     """Import a SIRP object from XML.
     """
     grok.context(Interface)
-    grok.provides(ISIRPXMLImporter)
+    grok.provides(IKOFAXMLImporter)
 
     def __init__(self, context):
         self.context = context
-    
+
     def doImport(self, filepath):
         xml = None
@@ -40,11 +40,11 @@
 
 class Exporter(grok.Adapter):
-    """Export a SIRP object as pickle.
+    """Export a KOFA object as pickle.
 
     This all-purpose exporter exports attributes defined in schemata
@@ -61,5 +61,5 @@
 
 class XMLExporter(grok.Adapter):
-    """Export a SIRP object as XML.
+    """Export a KOFA object as XML.
 
     This all-purpose exporter exports XML representations of pickable
@@ -84,12 +84,12 @@
 
 class XMLImporter(grok.Adapter):
-    """Import a SIRP object from XML.
+    """Import a KOFA object from XML.
     """
     grok.context(Interface)
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/logger.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/logger.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/logger.py	(revision 7811)
@@ -19,6 +19,6 @@
 Convenience stuff for logging.
 
-Main component of :mod:`waeup.sirp.utils.logging` is a mix-in class
-:class:`waeup.sirp.utils.logging.Logger`. Classes derived (also) from
+Main component of :mod:`waeup.kofa.utils.logging` is a mix-in class
+:class:`waeup.kofa.utils.logging.Logger`. Classes derived (also) from
 that mix-in provide a `logger` attribute that returns a regular Python
 logger logging to a rotating log file stored in the datacenter storage
@@ -30,5 +30,5 @@
 The `logger_name` tells under which name the logger should be
 registered Python-wise. This is usually a dotted name string like
-``waeup.sirp.${sitename}.mycomponent`` which should be unique. If you
+``waeup.kofa.${sitename}.mycomponent`` which should be unique. If you
 pick a name already used by another component, trouble is ahead. The
 ``${sitename}`` chunk of the name can be set literally like this. The
@@ -46,9 +46,9 @@
 your `logger_name` and `logger_filename` attribute and off you go::
 
-  from waeup.sirp.utils.logger import Logger
+  from waeup.kofa.utils.logger import Logger
 
   class MyComponent(object, Logger):
       # Yes that's a complete working class
-      logger_name = 'waeup.sirp.${sitename}.mycomponent
+      logger_name = 'waeup.kofa.${sitename}.mycomponent
       logger_filename = 'mycomponent.log'
 
@@ -67,5 +67,5 @@
 
 The datacenter and its storage are created automatically when you
-create a :class:`waeup.sirp.app.University`. This also means that
+create a :class:`waeup.kofa.app.University`. This also means that
 logging with the `Logger` mix-in will work only inside so-called sites
 (`University` instances put into ZODB are such `sites`).
@@ -80,7 +80,7 @@
 from zope.component import queryUtility
 from zope.interface import Interface, Attribute, implements
-from waeup.sirp.interfaces import (
+from waeup.kofa.interfaces import (
     IDataCenter, IDataCenterStorageMovedEvent, ILoggerCollector)
-from waeup.sirp.utils.helpers import get_current_principal
+from waeup.kofa.utils.helpers import get_current_principal
 
 #: Default logfile size (5 KB)
@@ -152,8 +152,8 @@
 
     #: The Python logger name used when
     #: logging. ``'waeup.sirp.${sitename}'`` by default. You can use the
     #: ``${sitename}`` placeholder in that string, which will be
     #: replaced by the actual used site name.
-    logger_name = 'waeup.sirp.${sitename}'
+    logger_name = 'waeup.kofa.${sitename}'
     implements(ILogger)
 
@@ -378,5 +378,5 @@
     return
 
-from waeup.sirp.interfaces import IUniversity
+from waeup.kofa.interfaces import IUniversity
 @grok.subscribe(IUniversity, grok.IObjectRemovedEvent)
 def handle_site_removed(obj, event):
@@ -152,8 +152,8 @@
 
     #: The Python logger name used when
-    #: logging. ``'waeup.sirp.${sitename}'`` by default. You can use the
+    #: logging. ``'waeup.kofa.${sitename}'`` by default. You can use the
     #: ``${sitename}`` placeholder in that string, which will be
     #: replaced by the actual used site name.
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/tests/test_logger.py	(revision 7811)
@@ -17,5 +17,5 @@
 ##
 
 # Tests for waeup.sirp.utils.logger
 import logging
 import os
@@ -25,8 +25,8 @@
 from zope.component.hooks import setSite, clearSite
 from zope.interface.verify import verifyClass, verifyObject
-from waeup.sirp.app import University
-from waeup.sirp.testing import FunctionalLayer, FunctionalTestCase
-
-from waeup.sirp.utils.logger import (
+from waeup.kofa.app import University
+from waeup.kofa.testing import FunctionalLayer, FunctionalTestCase
+
+from waeup.kofa.utils.logger import (
     Logger, MAX_BYTES, BACKUP_COUNT, ILoggerCollector, LoggerCollector,
     ILogger)
@@ -17,5 +17,5 @@
 ##
 
-# Tests for waeup.sirp.utils.logger
+# Tests for waeup.kofa.utils.logger
 import logging
 import os
Index: main/waeup.kofa/trunk/src/waeup/kofa/utils/utils.py
===================================================================
--- main/waeup.kofa/trunk/src/waeup/kofa/utils/utils.py	(revision 7809)
+++ main/waeup.kofa/trunk/src/waeup/kofa/utils/utils.py	(revision 7811)
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
 """General helper utilities for SIRP.
 """
 import os
@@ -23,10 +23,10 @@
 from zope.i18n import translate
 from random import SystemRandom as r
-from waeup.sirp.interfaces import ISIRPUtils
-from waeup.sirp.interfaces import MessageFactory as _
-from waeup.sirp.smtp import send_mail as send_mail_internally
+from waeup.kofa.interfaces import IKOFAUtils
+from waeup.kofa.interfaces import MessageFactory as _
+from waeup.kofa.smtp import send_mail as send_mail_internally
 
 def send_mail(from_name,from_addr,rcpt_name,rcpt_addr,subject,body,config):
     """Wrapper for the real SMTP functionality in :mod:`waeup.sirp.smtp`.
 
     Merely here to stay compatible with lots of calls to this place.
@@ -37,8 +37,8 @@
     return True
 
-class SIRPUtils(grok.GlobalUtility):
+class KOFAUtils(grok.GlobalUtility):
     """A collection of parameters and methods subject to customization.
     """
-    grok.implements(ISIRPUtils)
+    grok.implements(IKOFAUtils)
     # This the only place where we define the portal language
     # which is used for the translation of system messages
@@ -131,5 +131,5 @@
             'd':portal,
             'e':body})
-        body = translate(text, 'waeup.sirp',
+        body = translate(text, 'waeup.kofa',
             target_language=self.PORTAL_LANGUAGE)
         return send_mail(
@@ -161,5 +161,5 @@
         Returns True or False to indicate successful operation.
         """
-        subject = 'Your SIRP credentials'
+        subject = 'Your KOFA credentials'
         text = _(u"""Dear ${a},
 
@@ -193,5 +193,5 @@
             'f':login_url})
 
-        body = translate(text, 'waeup.sirp',
+        body = translate(text, 'waeup.kofa',
             target_language=self.PORTAL_LANGUAGE)
         return send_mail(
@@ -16,5 +16,5 @@
 ## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 ##
-"""General helper utilities for SIRP.
+"""General helper utilities for KOFA.
 """
 import os
@@ -23,10 +23,10 @@
 
 def send_mail(from_name,from_addr,rcpt_name,rcpt_addr,subject,body,config):
-    """Wrapper for the real SMTP functionality in :mod:`waeup.sirp.smtp`.
+    """Wrapper for the real SMTP functionality in :mod:`waeup.kofa.smtp`.
 
     Merely here to stay compatible with lots of calls to this place.
